/*
 * File      : stack.c
 * This file is part of RT-Thread RTOS
 * COPYRIGHT (C) 2013, RT-Thread Development Team
 *
 * The license and distribution terms for this file may be
 * found in the file LICENSE in this distribution or at
 * http://www.rt-thread.org/license/LICENSE
 *
 * Change Logs:
 * Date           Author       Notes
 * 2011-09-23     Bernard      the first version
 * 2011-10-05     Bernard      add thumb mode
 * 2013-07-15     Bernard      add Cortex-A8 support.
 */
#include <rtthread.h>
#include "zynq7000.h"

/**
 * This function will initialize thread stack
 *
 * @param tentry the entry of thread
 * @param parameter the parameter of entry
 * @param stack_addr the beginning stack address
 * @param texit the function will be called when thread exit
 *
 * @return stack address
 */
rt_uint8_t *rt_hw_stack_init(void *tentry, void *parameter,
                             rt_uint8_t *stack_addr, void *texit)
{
    rt_uint32_t *stk;

    stk      = (rt_uint32_t *)stack_addr;
    *(stk)   = (rt_uint32_t)tentry;         /* entry point */
    *(--stk) = (rt_uint32_t)texit;          /* lr */
    *(--stk) = 0;                           /* r12 */
    *(--stk) = 0;                           /* r11 */
    *(--stk) = 0;                           /* r10 */
    *(--stk) = 0;                           /* r9 */
    *(--stk) = 0;                           /* r8 */
    *(--stk) = 0;                           /* r7 */
    *(--stk) = 0;                           /* r6 */
    *(--stk) = 0;                           /* r5 */
    *(--stk) = 0;                           /* r4 */
    *(--stk) = 0;                           /* r3 */
    *(--stk) = 0;                           /* r2 */
    *(--stk) = 0;                           /* r1 */
    *(--stk) = (rt_uint32_t)parameter;      /* r0 : argument */

    /* cpsr */
    if ((rt_uint32_t)tentry & 0x01)
        *(--stk) = SVCMODE | 0x20;          /* thumb mode */
    else
        *(--stk) = SVCMODE;                 /* arm mode   */

    /* return task's current stack address */
    return (rt_uint8_t *)stk;
}

